agentle.agents.whatsapp.providers.evolution.evolution\_api\_config
==================================================================

.. automodule:: agentle.agents.whatsapp.providers.evolution.evolution_api_config

   
   .. rubric:: Functions

   .. autosummary::
   
      Field
   
   .. rubric:: Classes

   .. autosummary::
   
      BaseModel
      EvolutionAPIConfig
   